package com.adictos.test;

import java.io.InputStream;
import java.sql.Connection;
import java.sql.Driver;
import java.sql.DriverManager;

import org.dbunit.database.DatabaseConfig;
import org.dbunit.database.DatabaseConnection;
import org.dbunit.database.IDatabaseConnection;
import org.dbunit.dataset.IDataSet;
import org.dbunit.dataset.stream.IDataSetProducer;
import org.dbunit.dataset.stream.StreamingDataSet;
import org.dbunit.dataset.xml.FlatXmlProducer;
import org.dbunit.ext.hsqldb.HsqldbDataTypeFactory;
import org.dbunit.operation.DatabaseOperation;
import org.springframework.core.io.ClassPathResource;
import org.springframework.jdbc.core.simple.SimpleJdbcTemplate;
import org.springframework.jdbc.datasource.DriverManagerDataSource;
import org.springframework.test.jdbc.SimpleJdbcTestUtils;
import org.xml.sax.InputSource;

/**
 * Clase para trabajar
 * como la librería de DBUnit
 * 
 *
 */
public class DBUnitUtils {
	
	/**
	 * Rellena la base de datos con la información almacenada de un fichero XML.
	 */
	public static void createData(String driverName, String urlDB, String userDB, String passworDB, String nameXML) throws Exception  {

		Connection conn = null;
		// Connect to the database
		DriverManager.registerDriver((Driver)Class.forName(driverName).newInstance());
		conn = DriverManager.getConnection(urlDB, userDB, passworDB);
		IDatabaseConnection connection = new DatabaseConnection(conn);

		// Configuramos DBUnit para usar un large dataset
		DatabaseConfig config = connection.getConfig();
		config.setProperty(DatabaseConfig.PROPERTY_DATATYPE_FACTORY, new HsqldbDataTypeFactory());
		
		//Recuperamos el fichero con los datos a cargar
		InputStream is = DBUnitUtils.class.getClassLoader().getResourceAsStream(nameXML + ".xml");
		
			
		IDataSetProducer producer = new FlatXmlProducer(new InputSource(DBUnitUtils.class.getClassLoader().getResourceAsStream(nameXML + ".xml")));

		IDataSet dataSet = new StreamingDataSet(producer);

		//Insertamos los datos
		DatabaseOperation.INSERT.execute(connection, dataSet);

		conn.close();
	}
	
	/**
	 * Ejecuta un script en la base de datos.
	 */
	public static void executeSql(String driverName, String urlDB, String userDB, String passwordDB, String nameSql) {
		//Ejecutamos el ddl utilizanod la clase de utilidad que nos ofrece spring
		SimpleJdbcTestUtils.executeSqlScript(new SimpleJdbcTemplate(new DriverManagerDataSource(driverName,urlDB,userDB,passwordDB)), new ClassPathResource(nameSql+".sql"), false);		

	}

}
